@@ -28,11 +28,11 @@ AE - simpler/faster/newer/cooler AnyEvent API
   # called when event loop idle (if applicable)
   my $w = AE::idle sub { ... };
 
-  my $w = AE::cv; # stores whether a condition was flagged
-  $w->send; # wake up current and all future recv's
-  $w->recv; # enters "main loop" till $condvar gets ->send
+  my $cv = AE::cv; # stores whether a condition was flagged
+  $cv->send; # wake up current and all future recv's
+  $cv->recv; # enters "main loop" till $condvar gets ->send
   # use a condvar in callback mode:
-  $w->cb (sub { $_[0]->recv });
+  $cv->cb (sub { $_[0]->recv });
 
 
 =head1 DESCRIPTION
@@ -55,12 +55,8 @@ Also, some backends (Perl and EV) are so fast that the method call
 overhead is very noticeable (with EV it increases the execution time five-
 to six-fold, with Perl the method call overhead is about a factor of two).
 
-At the moment, there is no checking (L<AnyEvent::Strict> does not
-affect this API), so the L<AnyEvent> API still has a definite advantage
-here.
-
 Note that the C<AE> API is an alternative to, not the future version of,
-the AnyEvent API. Both APIs can be used interchangeably and and there are
+the AnyEvent API. Both APIs can be used interchangeably and there are
 no plans to "switch", so if in doubt, feel free to use the L<AnyEvent>
 API in new code.
 
@@ -69,11 +65,15 @@ available, and you still need to use AnyEvent for the finer stuff. Also,
 you should not C<use AE> directly, C<use AnyEvent> will provide the AE
 namespace.
 
+At the moment, these functions will become slower then their method-call
+counterparts when using L<AnyEvent::Strict> or L<AnyEvent::Debug>::wrap.
+
 =head2 FUNCTIONS
 
-This section briefly describes the alternative watcher
-constructors. Semantics are not described here; please
-refer to the L<AnyEvent> manpage for the details.
+This section briefly describes the alternative watcher constructors and
+other functions available inside the C<AE> namespace. Semantics are not
+described here; please refer to the description of the function or method
+with the same name in the L<AnyEvent> manpage for the details.
 
 =over 4
 
@@ -161,6 +161,10 @@ Return the current time (not cached, always consults a hardware clock).
 
 Exactly the same as C<AnyEvent:::postpone>.
 
+=item AE::log $level, $msg[, @args]
+
+Exactly the same as C<AnyEvent::log> (or C<AnyEvent::Log::log>).
+
 =back
 
 =head1 AUTHOR
